@@ -9,10 +9,9 @@ LOGGER = logging.getLogger("PYWPS")
 
 
 class Metadata(object):
-    """
-    ows:Metadata content model.
+    """ows:Metadata content model.
 
-    :param title: Metadata title, human readable string
+    :param title: Metadata title, human-readable string
     :param href: fully qualified URL
     :param role: fully qualified URL
     :param type_: fully qualified URL
@@ -36,8 +35,7 @@ class Metadata(object):
 
     @property
     def json(self):
-        """Get JSON representation of the metadata
-        """
+        """Get JSON representation of the metadata."""
         data = {
             'title': self.title,
             'href': self.href,
@@ -70,7 +68,7 @@ class MetadataUrl(Metadata):
 
     Useful to avoid Sphinx "Duplicate explicit target name" warning.
 
-    See https://docutils.sourceforge.io/docs/ref/rst/restructuredtext.html#anonymous-hyperlinks.
+    See: https://docutils.sourceforge.io/docs/ref/rst/restructuredtext.html#anonymous-hyperlinks.
 
     Meant to use in documentation only, not needed in the xml response, nor being serialized or
     deserialized to/from json.  So that's why it is not directly in the base class.
