@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
+from docutils.parsers.rst import directives
 from sphinx.ext.autodoc import ClassDocumenter, bool_option
 from sphinx.ext.napoleon.docstring import NumpyDocstring
 from sphinx.util.docstrings import prepare_docstring
-from docutils.parsers.rst import directives
+
 from pywps import Process
 from pywps.app.Common import Metadata, MetadataUrl
 
@@ -120,7 +121,7 @@ class ProcessDocumenter(ClassDocumenter):
         for m in obj.metadata:
             if isinstance(m, Metadata):
                 title, href = m.title, m.href
-            elif type(m) == dict:
+            elif isinstance(m, dict):
                 title, href = m['title'], m['href']
             else:
                 title, href = None, None
