@@ -3,7 +3,7 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
-from pywps.inout.inputs import LiteralInput, ComplexInput, BoundingBoxInput
-from pywps.inout.outputs import LiteralOutput, ComplexOutput, BoundingBoxOutput
-from pywps.inout.formats import Format, FORMATS, get_format
 from pywps.inout.basic import UOM
+from pywps.inout.formats import FORMATS, Format, get_format
+from pywps.inout.inputs import BoundingBoxInput, ComplexInput, LiteralInput
+from pywps.inout.outputs import BoundingBoxOutput, ComplexOutput, LiteralOutput
