@@ -3,7 +3,7 @@
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
 
-import unittest
+from basic import TestBase
 from pywps import configuration
 from pywps.app import Process, Service
 from pywps.app.Common import Metadata
@@ -13,7 +13,7 @@ from pywps.tests import client_for, assert_wps_version
 WPS, OWS = get_ElementMakerForVersion("1.0.0")
 
 
-class BadRequestTest(unittest.TestCase):
+class BadRequestTest(TestBase):
 
     def test_bad_http_verb(self):
         client = client_for(Service())
@@ -42,9 +42,11 @@ class BadRequestTest(unittest.TestCase):
         assert resp.status_code == 400
 
 
-class CapabilitiesTest(unittest.TestCase):
+class CapabilitiesTest(TestBase):
 
     def setUp(self):
+        super().setUp()
+
         def pr1(): pass
         def pr2(): pass
         self.client = client_for(
@@ -97,11 +99,12 @@ class CapabilitiesTest(unittest.TestCase):
         assert len(metadatas) == 2
 
     def test_get_request(self):
-        resp = self.client.get('?Request=GetCapabilities&service=WpS')
+        # Check service=WPS (parameters values are case sensitive)
+        resp = self.client.get('?Request=GetCapabilities&service=WPS')
         self.check_capabilities_response(resp)
 
-        # case insesitive check
-        resp = self.client.get('?request=getcapabilities&service=wps')
+        # Check service=WPS (parameters name are not sensitive to case)
+        resp = self.client.get('?ReQuest=GetCapabilities&SeRviCe=WPS')
         self.check_capabilities_response(resp)
 
     def test_post_request(self):
@@ -110,7 +113,7 @@ class CapabilitiesTest(unittest.TestCase):
         self.check_capabilities_response(resp)
 
     def test_get_bad_version(self):
-        resp = self.client.get('?request=getcapabilities&service=wps&acceptversions=2001-123')
+        resp = self.client.get('?request=getcapabilities&service=WPS&acceptversions=2001-123')
         exception = resp.xpath('/ows:ExceptionReport'
                                '/ows:Exception')
         assert resp.status_code == 400
@@ -135,9 +138,9 @@ class CapabilitiesTest(unittest.TestCase):
         assert_wps_version(resp, version="2.0.0")
 
 
-class CapabilitiesTranslationsTest(unittest.TestCase):
+class CapabilitiesTranslationsTest(TestBase):
     def setUp(self):
-        configuration.load_configuration()
+        super().setUp()
         configuration.CONFIG.set('server', 'language', 'en-US,fr-CA')
         self.client = client_for(
             Service(
@@ -160,11 +163,8 @@ class CapabilitiesTranslationsTest(unittest.TestCase):
             )
         )
 
-    def tearDown(self):
-        configuration.CONFIG.set('server', 'language', 'en-US')
-
     def test_get_translated(self):
-        resp = self.client.get('?Request=GetCapabilities&service=wps&language=fr-CA')
+        resp = self.client.get('?Request=GetCapabilities&service=WPS&language=fr-CA')
 
         assert resp.xpath('/wps:Capabilities/@xml:lang')[0] == "fr-CA"
 
@@ -180,6 +180,8 @@ class CapabilitiesTranslationsTest(unittest.TestCase):
 
 
 def load_tests(loader=None, tests=None, pattern=None):
+    import unittest
+
     if not loader:
         loader = unittest.TestLoader()
     suite_list = [
