@@ -6,7 +6,7 @@
 """Unit tests for processing
 """
 
-import unittest
+from basic import TestBase
 
 import json
 import uuid
@@ -18,17 +18,21 @@ from pywps.processing.basic import MultiProcessing
 from pywps.app import WPSRequest
 from pywps.response.execute import ExecuteResponse
 
-from .processes import Greeter, InOut, BBox
+from processes import Greeter, InOut, BBox
 
 
-class GreeterProcessingTest(unittest.TestCase):
+class GreeterProcessingTest(TestBase):
     """Processing test case with Greeter process"""
 
     def setUp(self):
+        super().setUp()
+
+        self.workdir = pywps.configuration.get_config_value('server', 'workdir')
+
         self.uuid = uuid.uuid1()
         self.dummy_process = Greeter()
         self.dummy_process._set_uuid(self.uuid)
-        self.dummy_process.set_workdir('/tmp')
+        self.dummy_process.set_workdir(self.workdir)
         self.wps_request = WPSRequest()
         self.wps_response = ExecuteResponse(self.wps_request, self.uuid,
                                             process=self.dummy_process)
@@ -53,25 +57,29 @@ class GreeterProcessingTest(unittest.TestCase):
         new_job = Job.from_json(json.loads(self.job.json))
         self.assertEqual(new_job.name, 'greeter')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 1)
 
     def test_job_dump(self):
         new_job = Job.load(self.job.dump())
         self.assertEqual(new_job.name, 'greeter')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 1)
 
 
-class InOutProcessingTest(unittest.TestCase):
+class InOutProcessingTest(TestBase):
     """Processing test case with InOut process"""
 
     def setUp(self):
+        super().setUp()
+
+        self.workdir = pywps.configuration.get_config_value('server', 'workdir')
+
         self.uuid = uuid.uuid1()
         self.dummy_process = InOut()
         self.dummy_process._set_uuid(self.uuid)
-        self.dummy_process.set_workdir('/tmp')
+        self.dummy_process.set_workdir(self.workdir)
         self.wps_request = WPSRequest()
         self.wps_response = ExecuteResponse(self.wps_request, self.uuid,
                                             process=self.dummy_process)
@@ -84,7 +92,7 @@ class InOutProcessingTest(unittest.TestCase):
         new_job = Job.from_json(json.loads(self.job.json))
         self.assertEqual(new_job.name, 'inout')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 3)
         self.assertEqual(new_job.json, self.job.json)  # idempotent test
 
@@ -92,19 +100,23 @@ class InOutProcessingTest(unittest.TestCase):
         new_job = Job.load(self.job.dump())
         self.assertEqual(new_job.name, 'inout')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 3)
         self.assertEqual(new_job.json, self.job.json)  # idempotent test
 
 
-class BBoxProcessingTest(unittest.TestCase):
+class BBoxProcessingTest(TestBase):
     """Processing test case with BBox input and output process"""
 
     def setUp(self):
+        super().setUp()
+
+        self.workdir = pywps.configuration.get_config_value('server', 'workdir')
+
         self.uuid = uuid.uuid1()
         self.dummy_process = BBox()
         self.dummy_process._set_uuid(self.uuid)
-        self.dummy_process.set_workdir('/tmp')
+        self.dummy_process.set_workdir(self.workdir)
         self.wps_request = WPSRequest()
         self.wps_response = ExecuteResponse(self.wps_request, self.uuid,
                                             process=self.dummy_process)
@@ -117,7 +129,7 @@ class BBoxProcessingTest(unittest.TestCase):
         new_job = Job.from_json(json.loads(self.job.json))
         self.assertEqual(new_job.name, 'bbox_test')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 1)
         self.assertEqual(new_job.json, self.job.json)  # idempotent test
 
@@ -125,7 +137,7 @@ class BBoxProcessingTest(unittest.TestCase):
         new_job = Job.load(self.job.dump())
         self.assertEqual(new_job.name, 'bbox_test')
         self.assertEqual(new_job.uuid, str(self.uuid))
-        self.assertEqual(new_job.workdir, '/tmp')
+        self.assertEqual(new_job.workdir, self.workdir)
         self.assertEqual(len(new_job.process.inputs), 1)
         self.assertEqual(new_job.json, self.job.json)  # idempotent test
 
@@ -133,6 +145,8 @@ class BBoxProcessingTest(unittest.TestCase):
 def load_tests(loader=None, tests=None, pattern=None):
     """Load local tests
     """
+    import unittest
+
     if not loader:
         loader = unittest.TestLoader()
     suite_list = [
